Base schema: http://purl.allotrope.org/json-schemas/adm/binding-affinity-analyzer/WD/2024/12/binding-affinity-analyzer.embed.schema


Changes:

* Changed Nanomolar unit from "nmol/dm^3" to "nM"
  * Reasoning: To match other representations of molar concentration units
  * Proposal: update unit notation of Nanomolar from "nmol/dm^3" to "nM"
  * NOTE: proposed for the updation in the allotrope units.schema
